@@ -1,5 +1,4 @@
-"""
-Entry-point module, in case you use `python -m dependenpy`.
+"""Entry-point module, in case you use `python -m dependenpy`.
 
 Why does this file exist, and why __main__? For more info, read:
 
@@ -10,7 +9,7 @@ Why does this file exist, and why __main__? For more info, read:
 
 import sys
 
-from dependenpy.cli import main
+from dependenpy._internal.cli import main
 
 if __name__ == "__main__":
     sys.exit(main(sys.argv[1:]))
